@@ -7,9 +7,9 @@
 # Autotool versions preferred. To override either edit the script
 # to match the versions you want to use, or set the variables on
 # the command line like "env acver=.. amver=... ./bootstrap.sh"
-acversions="${acver:-2.63 2.62 2.61}"
+acversions="${acver:-2.64 2.63 2.62 2.61}"
 amversions="${amver:-1.11 1.10 1.9}"
-ltversions="${ltver:-2.2 1.5 1.4}"
+ltversions="${ltver:-2.2}"
 
 check_version()
 {
@@ -64,6 +64,18 @@ find_variant()
   echo $found
 }
 
+find_path()
+{
+  tool=$1
+  path=`which $tool`
+  if test $? -gt 0 ; then
+    # path for $tool not found. Not defining, and hoping for the best
+    echo 
+    return
+  fi
+  echo $(dirname $path)
+}
+
 bootstrap() {
   if "$@"; then
     true # Everything OK
@@ -82,12 +94,7 @@ bootstrap_libtoolize() {
     # instead of manualy moving files from ltdl to lib/libLtdl
     if egrep -q '^[[:space:]]*AC_LIBLTDL_' configure.in
     then
-	if libtoolize$ltver --help | grep -q -- --ltdl.=; then
-	    ltdl="--ltdl=lib/libLtdl"
-	else
-	    ltdl="--ltdl"
-	    copy_libltdl=1
-	fi
+	ltdl="--ltdl"
     else
         ltdl=""
     fi
@@ -95,7 +102,7 @@ bootstrap_libtoolize() {
     bootstrap libtoolize$ltver $ltdl --force --copy --automake
 
     # customize generated libltdl, if any
-    if test -d libltdl && [ $copy_libltdl ]
+    if test -d libltdl
     then
         src=libltdl
 
@@ -106,19 +113,6 @@ bootstrap_libtoolize() {
         chmod u+w $makefile
         mv $makefile.new $makefile
         chmod u-w $makefile
-
-        dest=lib/libLtdl
-        # move $src to $dest
-	if test -d $dest # already exists
-	then
-	    echo "Updating $dest from $src."
-            chmod u+w $dest/*
-            mv $src/* $dest/
-            rmdir $src
-	else
-	    echo "Creating $dest from $src."
-	    mv $src $dest
-        fi
     fi
 }
 
@@ -132,12 +126,16 @@ amversion=`show_version automake ${amversions}`
 acversion=`show_version autoconf ${acversions}`
 ltversion=`show_version libtool ${ltversions}`
 
+# Find the libtool path to get the right aclocal includes
+ltpath=`find_path libtool$ltver`
+
 # Set environment variable to tell automake which autoconf to use.
 AUTOCONF="autoconf${acver}" ; export AUTOCONF
 
 echo "automake ($amversion) : automake$amver"
 echo "autoconf ($acversion) : autoconf$acver"
 echo "libtool  ($ltversion) : libtool$ltver"
+echo "libtool path : $ltpath"
 
 for dir in \
 	"" \
@@ -153,9 +151,15 @@ do
 	elif [ ! -f $dir/configure ]; then
 	    # Make sure cfgaux exists
 	    mkdir -p cfgaux
+            
+            if test -n "$ltpath"; then
+              acincludeflag="-I $ltpath/../share/aclocal"
+            else
+              acincludeflag=""
+            fi
 
 	    # Bootstrap the autotool subsystems
-	    bootstrap aclocal$amver
+	    bootstrap aclocal$amver $acincludeflag
 	    bootstrap autoheader$acver
 	    bootstrap_libtoolize $ltver
 	    bootstrap automake$amver --foreign --add-missing --copy -f
